==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstgbopvragen/v20130701/BestandenlijstGBOpvragenResponse.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstgbopvragen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragenresultaat.v20130701.BestandenlijstGbOpvragenResultaatType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="antwoord" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbopvragenresultaat/v20130701}BestandenlijstGbOpvragenResultaatType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "antwoord"
})
@XmlRootElement(name = "BestandenlijstGBOpvragenResponse")
public class BestandenlijstGBOpvragenResponse {

    @XmlElement(required = true)
    protected BestandenlijstGbOpvragenResultaatType antwoord;

    /**
     * Gets the value of the antwoord property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenlijstGbOpvragenResultaatType }
     *     
     */
    public BestandenlijstGbOpvragenResultaatType getAntwoord() {
        return antwoord;
    }

    /**
     * Sets the value of the antwoord property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenlijstGbOpvragenResultaatType }
     *     
     */
    public void setAntwoord(BestandenlijstGbOpvragenResultaatType value) {
        this.antwoord = value;
    }

}

==> kadaster-gds2-2.3-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandenlijstgbopvragen/v20130701/BestandenlijstGBOpvragenResponse.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandenlijstgbopvragen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbopvragenresultaat.v20130701.BestandenlijstGbOpvragenResultaatType;


/**
 * &lt;p&gt;Java class for anonymous complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="antwoord" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstgbopvragenresultaat/v20130701}BestandenlijstGbOpvragenResultaatType"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "antwoord"
})
@XmlRootElement(name = "BestandenlijstGBOpvragenResponse")
public class BestandenlijstGBOpvragenResponse {

    @XmlElement(required = true)
    protected BestandenlijstGbOpvragenResultaatType antwoord;

    /**
     * Gets the value of the antwoord property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenlijstGbOpvragenResultaatType }
     *     
     */
    public BestandenlijstGbOpvragenResultaatType getAntwoord() {
        return antwoord;
    }

    /**
     * Sets the value of the antwoord property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenlijstGbOpvragenResultaatType }
     *     
     */
    public void setAntwoord(BestandenlijstGbOpvragenResultaatType value) {
        this.antwoord = value;
    }

}
